@@ -46,6 +46,7 @@
 G_DEFINE_TYPE (ScreenshotApplication, screenshot_application, GTK_TYPE_APPLICATION);
 
 static void screenshot_save_to_file (ScreenshotApplication *self);
+static void screenshot_show_interactive_dialog (ScreenshotApplication *self);
 
 struct _ScreenshotApplicationPriv {
   gchar *icc_profile_base64;
@@ -456,10 +457,17 @@ rectangle_found_cb (GdkRectangle *rectangle,
   ScreenshotApplication *self = user_data;
 
   if (rectangle != NULL)
-    finish_prepare_screenshot (self, rectangle);
+    {
+      finish_prepare_screenshot (self, rectangle);
+    }
   else
-    /* user dismissed the rectangle with Esc, no error; just quit */
-    g_application_release (G_APPLICATION (self));
+    {
+      /* user dismissed the area selection, possibly show the dialog again */
+      g_application_release (G_APPLICATION (self));
+
+      if (screenshot_config->interactive)
+        screenshot_show_interactive_dialog (self);
+    }
 }
 
 static gboolean
@@ -643,6 +651,16 @@ interactive_dialog_response_cb (GtkWidget *d,
     }
 }
 
+static void
+screenshot_show_interactive_dialog (ScreenshotApplication *self)
+{
+  GtkWidget *dialog;
+
+  dialog = screenshot_interactive_dialog_new ();
+  g_signal_connect (dialog, "response",
+                    G_CALLBACK (interactive_dialog_response_cb), self);
+}
+
 static void
 action_quit (GSimpleAction *action,
              GVariant *parameter,
@@ -696,38 +714,30 @@ static void
 screenshot_application_startup (GApplication *app)
 {
   ScreenshotApplication *self = SCREENSHOT_APPLICATION (app);
+  GtkBuilder *builder;
+  GMenuModel *menu;
 
   G_APPLICATION_CLASS (screenshot_application_parent_class)->startup (app);
 
   gtk_window_set_default_icon_name (SCREENSHOOTER_ICON);
   screenshooter_init_stock_icons ();
 
+  g_action_map_add_action_entries (G_ACTION_MAP (self), action_entries,
+                                   G_N_ELEMENTS (action_entries), self);
+
+  builder = gtk_builder_new ();
+  gtk_builder_add_from_resource (builder, "/org/gnome/screenshot/screenshot-app-menu.ui", NULL);
+  menu = G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu"));
+  gtk_application_set_app_menu (GTK_APPLICATION (self), menu);
+
+  g_object_unref (builder);
+  g_object_unref (menu);
+
   /* interactive mode: trigger the dialog and wait for the response */
   if (screenshot_config->interactive)
-    {
-      GtkWidget *dialog;
-      GtkBuilder *builder;
-      GMenuModel *menu;
-
-      g_action_map_add_action_entries (G_ACTION_MAP (self), action_entries,
-                                       G_N_ELEMENTS (action_entries), self);
-
-      builder = gtk_builder_new ();
-      gtk_builder_add_from_resource (builder, "/org/gnome/screenshot/screenshot-app-menu.ui", NULL);
-      menu = G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu"));
-      gtk_application_set_app_menu (GTK_APPLICATION (self), menu);
-
-      g_object_unref (builder);
-      g_object_unref (menu);
-
-      dialog = screenshot_interactive_dialog_new ();
-      g_signal_connect (dialog, "response",
-                        G_CALLBACK (interactive_dialog_response_cb), self);
-    }
+    screenshot_show_interactive_dialog (self);
   else
-    {
-      screenshot_start (self);
-    }
+    screenshot_start (self);
 }
 
 static void
